<a href="https://flomoapp.com/"><img src="https://raw.githubusercontent.com/Benature/flomo/main/flomo/media/logo-192x192.png" height="100" align="right"></a>

# flomo 浮墨

[![PyPI](https://img.shields.io/pypi/v/autolatex)](https://pypi.org/project/flomo/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/flomo)
[![GitHub stars](https://img.shields.io/github/stars/Benature/AutoLaTeX)](https://github.com/Benature/flomo)

一个非官方的 API python 玩具盒

> *prefer python3.7+*  
> 欢迎 Star 🌟、Fork 🍴、Issue 💬、PR. 一起让 flomo 用的更加得心应手

## Usage 使用

```shell
pip install -U flomo
```

相关 workflow 示例可参考 [flomo workflow](https://github.com/Benature/flomo-workflow)

## Relative Project 相关项目

- workflow: [flomo workflow](https://github.com/Benature/flomo-workflow)
- npm: [flomo api helper](https://github.com/geekdada/flomo-api-helper)